utils::globalVariables(c(
  "provider_org_code",
  "provider_org_name",
  "mean_wait_weeks",
  "backlog_total",
  "period",
  "first_breach",
  "start_date",
  "end_date",
  "mean_wait",
  "volatility",
  "risk_flag",
  "is_breach",
  "is_volatile"
))
