% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/vowr_cox_model.R
\name{vowr_cox_model}
\alias{vowr_cox_model}
\title{Estimate Cox proportional hazards model for threshold breach}
\usage{
vowr_cox_model(surv_profile)
}
\arguments{
\item{surv_profile}{Data frame from vowr_survival_merge()}
}
\value{
A fitted Cox proportional hazards model
}
\description{
Estimate Cox proportional hazards model for threshold breach
}
