% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/vowr_plot.R
\name{vowr_plot}
\alias{vowr_plot}
\title{Visualize provider risk distribution}
\usage{
vowr_plot(flagged_data)
}
\arguments{
\item{flagged_data}{A data frame produced by vowr_flag()}
}
\value{
A ggplot object
}
\description{
Visualize provider risk distribution
}
