% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/vowr_profile.R
\name{vowr_profile}
\alias{vowr_profile}
\title{Profile National Health Service provider performance}
\usage{
vowr_profile(data)
}
\arguments{
\item{data}{A data frame from vowr_import().}
}
\value{
A summary table with the number of months, mean waiting time,
median waiting time, waiting-time volatility, and total backlog for each
provider.
}
\description{
Profile National Health Service provider performance
}
