% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/vowr_import.R
\name{vowr_import}
\alias{vowr_import}
\title{Import and validate RTT data}
\usage{
vowr_import(path = NULL)
}
\arguments{
\item{path}{Optional path to an NHS Referral-to-Treatment (RTT) CSV file.
If NULL, the example data included in the package is loaded.}
}
\value{
A cleaned data frame.
}
\description{
Import and validate RTT data
}
\examples{
sample_path <- system.file(
  "extdata",
  "rtt_trust_month_panel_last24_FIXED-2.csv",
  package = "VOWR"
)

data <- vowr_import(sample_path)
head(data)

}
