% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/vowr_survival_merge.R
\name{vowr_survival_merge}
\alias{vowr_survival_merge}
\title{Merge survival output with provider profile and risk flags}
\usage{
vowr_survival_merge(surv_result, profile, flagged)
}
\arguments{
\item{surv_result}{Output from vowr_survival()}

\item{profile}{Output from vowr_profile()}

\item{flagged}{Output from vowr_flag()}
}
\value{
A provider-level survival analysis data frame
}
\description{
Merge survival output with provider profile and risk flags
}
