% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/survival_plots.R
\name{plot_km_by_delay}
\alias{plot_km_by_delay}
\title{Kaplan-Meier plot by group}
\usage{
plot_km_by_delay(data, time, event, group)
}
\arguments{
\item{data}{A data frame.}

\item{time}{Name of duration/time variable.}

\item{event}{Name of event variable: 1 = event occurred, 0 = censored.}

\item{group}{Name of grouping variable.}
}
\value{
A survminer ggsurvplot object.
}
\description{
Kaplan-Meier plot by group
}
