% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/vowr_survival.R
\name{vowr_survival}
\alias{vowr_survival}
\title{Estimate time-to-breach survival model}
\usage{
vowr_survival(data, threshold = 18)
}
\arguments{
\item{data}{A data frame from vowr_import().}

\item{threshold}{Mean waiting-time threshold in weeks. Default is 18.}
}
\value{
A list containing a Kaplan-Meier survival model object and the data
used to fit the model.
}
\description{
Estimate time-to-breach survival model
}
