% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/vowr_km_by_risk.R
\name{vowr_km_by_risk}
\alias{vowr_km_by_risk}
\title{Kaplan-Meier plot by provider risk group}
\usage{
vowr_km_by_risk(surv_profile)
}
\arguments{
\item{surv_profile}{Data frame from vowr_survival_merge()}
}
\value{
A survminer Kaplan-Meier plot object
}
\description{
Kaplan-Meier plot by provider risk group
}
